@@ -1,30 +1,34 @@
 (ns clj-http.cookies
-  (:use [clojure.string :only [blank? join lower-case]])
+  (:require [clojure.string :refer [blank? join lower-case]])
   (:import (org.apache.http.client.params ClientPNames CookiePolicy)
            (org.apache.http.cookie ClientCookie CookieOrigin)
            (org.apache.http.params BasicHttpParams)
            (org.apache.http.impl.cookie BasicClientCookie2)
            (org.apache.http.impl.cookie BrowserCompatSpecFactory)
-           (org.apache.http.message BasicHeader)))
+           (org.apache.http.message BasicHeader)
+           org.apache.http.client.CookieStore))
 
-(defn- cookie-spec ^org.apache.http.cookie.CookieSpec []
+(defn cookie-spec ^org.apache.http.cookie.CookieSpec []
   (.newInstance
    (BrowserCompatSpecFactory.)
    (doto (BasicHttpParams.)
      (.setParameter ClientPNames/COOKIE_POLICY
                     CookiePolicy/BROWSER_COMPATIBILITY))))
 
-(defn- compact-map
+(defn compact-map
   "Removes all map entries where value is nil."
   [m]
-  (reduce #(if (get m %2) (assoc %1 %2 (get m %2)) %1)
+  (reduce (fn [newm k]
+            (if (not (nil? (get m k)))
+              (assoc newm k (get m k))
+              newm))
           (sorted-map) (sort (keys m))))
 
 (defn to-cookie
   "Converts a ClientCookie object into a tuple where the first item is
   the name of the cookie and the second item the content of the
   cookie."
-  [#^ClientCookie cookie]
+  [^ClientCookie cookie]
   [(.getName cookie)
    (compact-map
     {:comment (.getComment cookie)
@@ -38,20 +42,21 @@
      :value (.getValue cookie)
      :version (.getVersion cookie)})])
 
-(defn to-basic-client-cookie
+(defn ^org.apache.http.impl.cookie.BasicClientCookie2
+  to-basic-client-cookie
   "Converts a cookie seq into a BasicClientCookie2."
   [[cookie-name cookie-content]]
   (doto (BasicClientCookie2. (name cookie-name)
                              (name (:value cookie-content)))
     (.setComment (:comment cookie-content))
     (.setCommentURL (:comment-url cookie-content))
-    (.setDiscard (or (:discard cookie-content) true))
+    (.setDiscard (:discard cookie-content true))
     (.setDomain (:domain cookie-content))
     (.setExpiryDate (:expires cookie-content))
     (.setPath (:path cookie-content))
     (.setPorts (int-array (:ports cookie-content)))
-    (.setSecure (or (:secure cookie-content) false))
-    (.setVersion (or (:version cookie-content) 0))))
+    (.setSecure (:secure cookie-content false))
+    (.setVersion (:version cookie-content 0))))
 
 (defn decode-cookie
   "Decode the Set-Cookie string into a cookie seq."
@@ -108,7 +113,9 @@
     request))
 
 (defn wrap-cookies
-  "Middleware wrapping cookie handling."
+  "Middleware wrapping cookie handling. Handles converting
+  the :cookies request parameter into the 'Cookies' header for an HTTP
+  request."
   [client]
   (fn [request]
     (let [response (client (encode-cookie-header request))]
@@ -122,18 +129,6 @@
 
 (defn get-cookies
   "Given a cookie-store, return a map of cookie name to a map of cookie values."
-  [cookie-store]
+  [^CookieStore cookie-store]
   (when cookie-store
     (into {} (map to-cookie (.getCookies cookie-store)))))
-
-(defn wrap-cookie-store
-  "Middleware that sends cookies that are part of a cookie store automatically
-  with a request if the :cookie-store parameter is set."
-  [client]
-  (fn [req]
-    (if-let [cs (:cookie-store req)]
-      ;; If a cookie-store is supplied, merge the cookie-stores
-      ;; cookies with the request's cookies to send with the request
-      (let [new-req (merge-with merge req {:cookies (get-cookies cs)})]
-        (client new-req))
-      (client req))))
