@@ -5,6 +5,7 @@
             [com.puppetlabs.puppetdb.http.events :as events-http]
             [com.puppetlabs.jdbc :refer [with-transacted-connection]]
             [com.puppetlabs.middleware :refer [verify-accepts-json validate-query-params]]
+            [clojure.tools.logging :as log]
             [net.cgrand.moustache :refer [app]]))
 
 (defn produce-body
@@ -45,6 +46,7 @@
 (defn aggregate-event-counts-app
   "Ring app for querying for aggregated summary information about resource events."
   [version]
+  (log/warn "The aggregate-event-counts endpoint is experimental and may be altered or removed in the future.")
   (-> (routes version)
       verify-accepts-json
       (validate-query-params {:required ["query" "summarize-by"]
